# delimit ;
clear all;
set memory 400m;
set more off;

* Name of working directory;
local dir "C:\Users\davinchor\Documents\Projects\Trade-Production Line\Antras-Chor Replication Material";
cd "`dir'";

******************************************************;
* TABLE 2: BUYER VS SELLER CONTROLS (BASELINES) ;
******************************************************;

local mergelist "factorintensities randdintensity dispersion";

use USIOrelatedparty.dta, clear;
keep if year>=2000 & year<=2010;
collapse (sum) imp_non imp_rel, by(io2002 year);
gen imp_intrafirm = imp_rel/(imp_non+imp_rel);
lab var imp_intrafirm "Intrafirm imports";
gen tot_imp = imp_rel+imp_non;
la var tot_imp "Total imports";
foreach f of local mergelist {;
	merge n:1 io2002 using `f';
	drop if _m==2;
	drop _m;
};
keep if substr(io2002,1,1)=="3" & imp_intrafirm~=.;
compress;

local logfile Table2.log;
local ofile Table2.out;
local defoptions "dec(3) coefastr se bracket nocons excel";
cap erase `ofile';
cap erase `logfile';

cap log close;
log using `logfile', replace;

	areg imp_intrafirm year, absorb(year) cluster(io2002);
	outreg2 year using `ofile', replace `defoptions';

	
	/* UNWEIGHTED REGRESSIONS */
	/* Baselines using SELLER industry variables; */
	
	* Raw baseline;
	local factorcontrols "ls_l_0005 lk_l_0005";
	areg imp_intrafirm `factorcontrols', absorb(year) cluster(io2002);
	outreg2 `factorcontrols' using `ofile', append `defoptions' ctitle(`depvar');
	
	* Include dispersion, materials intensity and R&D intensity (US Orbis);
	local factorcontrols "ls_l_0005 lk_l_0005 lm_l_0005 lus_randd_intensity_0005";
	local disp "disp3_2000";
	areg imp_intrafirm `factorcontrols' `disp', absorb(year) cluster(io2002);
	outreg2 `factorcontrols' `disp' using `ofile', append `defoptions' ctitle(`depvar');
	
	* Breakdown capital intensity to equip and plant;
	local factorcontrols "ls_l_0005 lkequip_l_0005 lkplant_l_0005 lm_l_0005 lus_randd_intensity_0005";
	areg imp_intrafirm `factorcontrols' `disp', absorb(year) cluster(io2002);
	outreg2 `factorcontrols' `disp' using `ofile', append `defoptions' ctitle(`depvar');	


	/* New Baselines using BUYER industry variables; */	
	* Raw baseline;
	local wfactorcontrols "w1ls_l_0005 w1lk_l_0005";
	areg imp_intrafirm `wfactorcontrols', absorb(year) cluster(io2002);
	outreg2 `wfactorcontrols' using `ofile', append `defoptions' ctitle(`depvar');
	
	* Include dispersion, materials intensity and R&D intensity (US Orbis);
	local wfactorcontrols "w1ls_l_0005 w1lk_l_0005 w1lm_l_0005 w1lus_randd_intensity_0005";
	local wdisp "w1disp3_2000";
	areg imp_intrafirm `wfactorcontrols' `wdisp', absorb(year) cluster(io2002);
	outreg2 `wfactorcontrols' `wdisp' using `ofile', append `defoptions' ctitle(`depvar');
	
	* Breakdown capital intensity to equip and plant;
	local wfactorcontrols "w1ls_l_0005 w1lkequip_l_0005 w1lkplant_l_0005 w1lm_l_0005 w1lus_randd_intensity_0005";
	areg imp_intrafirm `wfactorcontrols' `wdisp', absorb(year) cluster(io2002);
	outreg2 `wfactorcontrols' `wdisp' using `ofile', append `defoptions' ctitle(`depvar');	

log close;
