# delimit ;
clear all;
set memory 400m;
set more off;

* Name of working directory;
local dir "C:\Users\davinchor\Documents\Projects\Trade-Production Line\Antras-Chor Replication Material";
cd "`dir'";

******************************************************;
* TABLE 8: TRIPLE INTERACTIONS WITH HQ INT QUINTILES ;
******************************************************;

use factorintensities.dta, clear;
merge 1:1 io2002 using randdintensity.dta;

* Generating principal components;
pca w1ls_l_0005 w1lkequip_l_0005 w1lus_randd_intensity_0005;
predict wpc1, score;
keep io2002 wpc1;
local factors "pc1";
foreach y of local factors {;
	xtile pw`y' = w`y', nq(10);
	g M1w`y'=0;
	replace M1w`y'=1 if pw`y'>=1 & pw`y'<=5;
	g M2w`y'=0;
	replace M2w`y'=1 if pw`y'>=6 & pw`y'<=10;
	g Q1w`y'=0;
	replace Q1w`y'=1 if pw`y'>=1 & pw`y'<=2;
	g Q2w`y'=0;
	replace Q2w`y'=1 if pw`y'>=3 & pw`y'<=4;
	g Q3w`y'=0;
	replace Q3w`y'=1 if pw`y'>=5 & pw`y'<=6;
	g Q4w`y'=0;
	replace Q4w`y'=1 if pw`y'>=7 & pw`y'<=8;
	g Q5w`y'=0;
	replace Q5w`y'=1 if pw`y'>=9 & pw`y'<=10;
	drop pw`y';
};
compress;
keep io2002 w`y' M1w`y' M2w`y' Q1w`y' Q2w`y' Q3w`y' Q4w`y' Q5w`y';
tempfile pc1;
save `pc1', replace;

local mergelist "downstreamness IOsigmas factorintensities 
 	randdintensity dispersion `pc1'";


* START WITH INDUSTRY-YEAR REGRESSIONS;

use USIOrelatedparty.dta, clear;
keep if year>=2000 & year<=2010;
collapse (sum) imp_non imp_rel, by(io2002 year);
gen imp_intrafirm = imp_rel/(imp_non+imp_rel);
lab var imp_intrafirm "Intrafirm imports";
gen tot_imp = imp_rel+imp_non;
la var tot_imp "Total imports";
foreach f of local mergelist {;
	merge n:1 io2002 using `f';
	drop if _m==2;
	drop _m;
};
keep if substr(io2002,1,1)=="3" & imp_intrafirm~=.;
compress;

foreach s of numlist 1/2 {;
	local m`s' w1M`s'sigma;
};
foreach s of numlist 1/5 {;
	local q`s' w1Q`s'sigma;
};

foreach t of numlist 1/5 {;
	local qh`t' Q`t'wpc1;
};

local logfile Table8.log;
local ofile Table8.out;
local defoptions "dec(3) coefastr se bracket nocons excel";
cap erase `ofile';
cap erase `logfile';

cap log close;
log using `logfile', replace;

	areg imp_intrafirm year, absorb(year) cluster(io2002);
	outreg2 year using `ofile', replace `defoptions';

	local dsvarlist "duse_tuse downmeasure";
	
	foreach dsvar of local dsvarlist {;
		foreach s of numlist 1/2 {;
			foreach t of numlist 1/5 {;
				cap drop `dsvar'X`m`s''X`qh`t'';
				g `dsvar'X`m`s''X`qh`t''=`dsvar'*`m`s''*`qh`t'';
				cap drop `m`s''X`qh`t'';
				g `m`s''X`qh`t''=`m`s''*`qh`t'';
			};
		};
	};
	
	* Columns 1 and 2; 
	local dsvar duse_tuse;
	
	local wfactorcontrols "w1ls_l_0005 w1lkequip_l_0005 w1lkplant_l_0005 w1lm_l_0005 w1lus_randd_intensity_0005";
	local wdisp "w1disp3_2000";
	
	areg imp_intrafirm `dsvar'X`m1'X`qh1' `dsvar'X`m1'X`qh2' `dsvar'X`m1'X`qh3' `dsvar'X`m1'X`qh4' `dsvar'X`m1'X`qh5' 
		`dsvar'X`m2'X`qh1' `dsvar'X`m2'X`qh2' `dsvar'X`m2'X`qh3' `dsvar'X`m2'X`qh4' `dsvar'X`m2'X`qh5' 
		`m1'X`qh1' `m1'X`qh2' `m1'X`qh3' `m1'X`qh4' `m1'X`qh5' `m2'X`qh2' `m2'X`qh3' `m2'X`qh4' `m2'X`qh5' `wfactorcontrols' `wdisp', 
		absorb(year) cluster(io2002);
	outreg2 `dsvar'X`m1'X`qh1' `dsvar'X`m1'X`qh2' `dsvar'X`m1'X`qh3' `dsvar'X`m1'X`qh4' `dsvar'X`m1'X`qh5' 
		`dsvar'X`m2'X`qh1' `dsvar'X`m2'X`qh2' `dsvar'X`m2'X`qh3' `dsvar'X`m2'X`qh4' `dsvar'X`m2'X`qh5' 
		`m1'X`qh1' `m1'X`qh2' `m1'X`qh3' `m1'X`qh4' `m1'X`qh5' `m2'X`qh2' `m2'X`qh3' `m2'X`qh4' `m2'X`qh5' `wfactorcontrols' `wdisp' using `ofile', 
		append `defoptions';
	test `dsvar'X`m1'X`qh1' `dsvar'X`m1'X`qh2' `dsvar'X`m1'X`qh3' `dsvar'X`m1'X`qh4' `dsvar'X`m1'X`qh5' 
		`dsvar'X`m2'X`qh1' `dsvar'X`m2'X`qh2' `dsvar'X`m2'X`qh3' `dsvar'X`m2'X`qh4' `dsvar'X`m2'X`qh5';
	test `dsvar'X`m1'X`qh1'-`dsvar'X`m1'X`qh5' = 0;
	test `dsvar'X`m1'X`qh1'-`dsvar'X`m1'X`qh4' = 0;
	test `dsvar'X`m2'X`qh1'-`dsvar'X`m2'X`qh5' = 0;
	
	areg imp_intrafirm `dsvar'X`m1'X`qh1' `dsvar'X`m1'X`qh2' `dsvar'X`m1'X`qh3' `dsvar'X`m1'X`qh4' `dsvar'X`m1'X`qh5' 
		`dsvar'X`m2'X`qh1' `dsvar'X`m2'X`qh2' `dsvar'X`m2'X`qh3' `dsvar'X`m2'X`qh4' `dsvar'X`m2'X`qh5' 
		`m1'X`qh1' `m1'X`qh2' `m1'X`qh3' `m1'X`qh4' `m1'X`qh5' `m2'X`qh2' `m2'X`qh3' `m2'X`qh4' `m2'X`qh5' `wfactorcontrols' `wdisp' [aw=tot_imp], 
		absorb(year) cluster(io2002);
	outreg2 `dsvar'X`m1'X`qh1' `dsvar'X`m1'X`qh2' `dsvar'X`m1'X`qh3' `dsvar'X`m1'X`qh4' `dsvar'X`m1'X`qh5' 
		`dsvar'X`m2'X`qh1' `dsvar'X`m2'X`qh2' `dsvar'X`m2'X`qh3' `dsvar'X`m2'X`qh4' `dsvar'X`m2'X`qh5' 
		`m1'X`qh1' `m1'X`qh2' `m1'X`qh3' `m1'X`qh4' `m1'X`qh5' `m2'X`qh2' `m2'X`qh3' `m2'X`qh4' `m2'X`qh5' `wfactorcontrols' `wdisp' using `ofile', 
		append `defoptions';
	test `dsvar'X`m1'X`qh1' `dsvar'X`m1'X`qh2' `dsvar'X`m1'X`qh3' `dsvar'X`m1'X`qh4' `dsvar'X`m1'X`qh5' 
		`dsvar'X`m2'X`qh1' `dsvar'X`m2'X`qh2' `dsvar'X`m2'X`qh3' `dsvar'X`m2'X`qh4' `dsvar'X`m2'X`qh5';
	test `dsvar'X`m1'X`qh1'-`dsvar'X`m1'X`qh5' = 0;
	test `dsvar'X`m1'X`qh1'-`dsvar'X`m1'X`qh4' = 0;
	test `dsvar'X`m2'X`qh1'-`dsvar'X`m2'X`qh5' = 0;
	

	* Columns 4 and 5;
	local dsvar downmeasure;
	
	areg imp_intrafirm `dsvar'X`m1'X`qh1' `dsvar'X`m1'X`qh2' `dsvar'X`m1'X`qh3' `dsvar'X`m1'X`qh4' `dsvar'X`m1'X`qh5' 
		`dsvar'X`m2'X`qh1' `dsvar'X`m2'X`qh2' `dsvar'X`m2'X`qh3' `dsvar'X`m2'X`qh4' `dsvar'X`m2'X`qh5' 
		`m1'X`qh1' `m1'X`qh2' `m1'X`qh3' `m1'X`qh4' `m1'X`qh5' `m2'X`qh2' `m2'X`qh3' `m2'X`qh4' `m2'X`qh5' `wfactorcontrols' `wdisp', 
		absorb(year) cluster(io2002);
	outreg2 `dsvar'X`m1'X`qh1' `dsvar'X`m1'X`qh2' `dsvar'X`m1'X`qh3' `dsvar'X`m1'X`qh4' `dsvar'X`m1'X`qh5' 
		`dsvar'X`m2'X`qh1' `dsvar'X`m2'X`qh2' `dsvar'X`m2'X`qh3' `dsvar'X`m2'X`qh4' `dsvar'X`m2'X`qh5' 
		`m1'X`qh1' `m1'X`qh2' `m1'X`qh3' `m1'X`qh4' `m1'X`qh5' `m2'X`qh2' `m2'X`qh3' `m2'X`qh4' `m2'X`qh5' `wfactorcontrols' `wdisp' using `ofile', 
		append `defoptions';
	test `dsvar'X`m1'X`qh1' `dsvar'X`m1'X`qh2' `dsvar'X`m1'X`qh3' `dsvar'X`m1'X`qh4' `dsvar'X`m1'X`qh5' 
		`dsvar'X`m2'X`qh1' `dsvar'X`m2'X`qh2' `dsvar'X`m2'X`qh3' `dsvar'X`m2'X`qh4' `dsvar'X`m2'X`qh5';
	test `dsvar'X`m1'X`qh1'-`dsvar'X`m1'X`qh5' = 0;
	test `dsvar'X`m1'X`qh1'-`dsvar'X`m1'X`qh4' = 0;
	test `dsvar'X`m2'X`qh1'-`dsvar'X`m2'X`qh5' = 0;
	
	areg imp_intrafirm `dsvar'X`m1'X`qh1' `dsvar'X`m1'X`qh2' `dsvar'X`m1'X`qh3' `dsvar'X`m1'X`qh4' `dsvar'X`m1'X`qh5' 
		`dsvar'X`m2'X`qh1' `dsvar'X`m2'X`qh2' `dsvar'X`m2'X`qh3' `dsvar'X`m2'X`qh4' `dsvar'X`m2'X`qh5' 
		`m1'X`qh1' `m1'X`qh2' `m1'X`qh3' `m1'X`qh4' `m1'X`qh5' `m2'X`qh2' `m2'X`qh3' `m2'X`qh4' `m2'X`qh5' `wfactorcontrols' `wdisp' [aw=tot_imp], 
		absorb(year) cluster(io2002);
	outreg2 `dsvar'X`m1'X`qh1' `dsvar'X`m1'X`qh2' `dsvar'X`m1'X`qh3' `dsvar'X`m1'X`qh4' `dsvar'X`m1'X`qh5' 
		`dsvar'X`m2'X`qh1' `dsvar'X`m2'X`qh2' `dsvar'X`m2'X`qh3' `dsvar'X`m2'X`qh4' `dsvar'X`m2'X`qh5' 
		`m1'X`qh1' `m1'X`qh2' `m1'X`qh3' `m1'X`qh4' `m1'X`qh5' `m2'X`qh2' `m2'X`qh3' `m2'X`qh4' `m2'X`qh5' `wfactorcontrols' `wdisp' using `ofile', 
		append `defoptions';
	test `dsvar'X`m1'X`qh1' `dsvar'X`m1'X`qh2' `dsvar'X`m1'X`qh3' `dsvar'X`m1'X`qh4' `dsvar'X`m1'X`qh5' 
		`dsvar'X`m2'X`qh1' `dsvar'X`m2'X`qh2' `dsvar'X`m2'X`qh3' `dsvar'X`m2'X`qh4' `dsvar'X`m2'X`qh5';
	test `dsvar'X`m1'X`qh1'-`dsvar'X`m1'X`qh5' = 0;
	test `dsvar'X`m1'X`qh1'-`dsvar'X`m1'X`qh4' = 0;
	test `dsvar'X`m2'X`qh1'-`dsvar'X`m2'X`qh5' = 0;
	
	
log close;



* COUNTRY-INDUSTRY-YEAR REGRESSIONS;

use USIOrelatedparty.dta, clear;
keep if year>=2000 & year<=2010;
collapse (sum) imp_non imp_rel, by(isocode io2002 year);
gen imp_intrafirm = imp_rel/(imp_non+imp_rel);
lab var imp_intrafirm "Intrafirm imports";
gen tot_imp = imp_rel+imp_non;
la var tot_imp "Total imports";
foreach f of local mergelist {;
	merge n:1 io2002 using `f';
	drop if _m==2;
	drop _m;
};
keep if substr(io2002,1,1)=="3" & imp_intrafirm~=.;
egen ctyyear=group(isocode year);
compress;

log using `logfile', append;


	local dsvarlist "duse_tuse downmeasure";
	
	foreach dsvar of local dsvarlist {;
		foreach s of numlist 1/2 {;
			foreach t of numlist 1/5 {;
				cap drop `dsvar'X`m`s''X`qh`t'';
				g `dsvar'X`m`s''X`qh`t''=`dsvar'*`m`s''*`qh`t'';
				cap drop `m`s''X`qh`t'';
				g `m`s''X`qh`t''=`m`s''*`qh`t'';
			};
		};
	};

	local wfactorcontrols "w1ls_l_0005 w1lkequip_l_0005 w1lkplant_l_0005 w1lm_l_0005 w1lus_randd_intensity_0005";
	local wdisp "w1disp3_2000";
	
	* Columns 3;
	local dsvar duse_tuse;
	
	areg imp_intrafirm `dsvar'X`m1'X`qh1' `dsvar'X`m1'X`qh2' `dsvar'X`m1'X`qh3' `dsvar'X`m1'X`qh4' `dsvar'X`m1'X`qh5' 
		`dsvar'X`m2'X`qh1' `dsvar'X`m2'X`qh2' `dsvar'X`m2'X`qh3' `dsvar'X`m2'X`qh4' `dsvar'X`m2'X`qh5' 
		`m1'X`qh1' `m1'X`qh2' `m1'X`qh3' `m1'X`qh4' `m1'X`qh5' `m2'X`qh2' `m2'X`qh3' `m2'X`qh4' `m2'X`qh5' `wfactorcontrols' `wdisp' [aw=tot_imp], 
		absorb(ctyyear) cluster(io2002);
	outreg2 `dsvar'X`m1'X`qh1' `dsvar'X`m1'X`qh2' `dsvar'X`m1'X`qh3' `dsvar'X`m1'X`qh4' `dsvar'X`m1'X`qh5' 
		`dsvar'X`m2'X`qh1' `dsvar'X`m2'X`qh2' `dsvar'X`m2'X`qh3' `dsvar'X`m2'X`qh4' `dsvar'X`m2'X`qh5' 
		`m1'X`qh1' `m1'X`qh2' `m1'X`qh3' `m1'X`qh4' `m1'X`qh5' `m2'X`qh2' `m2'X`qh3' `m2'X`qh4' `m2'X`qh5' `wfactorcontrols' `wdisp' using `ofile', 
		append `defoptions';
	test `dsvar'X`m1'X`qh1' `dsvar'X`m1'X`qh2' `dsvar'X`m1'X`qh3' `dsvar'X`m1'X`qh4' `dsvar'X`m1'X`qh5' 
		`dsvar'X`m2'X`qh1' `dsvar'X`m2'X`qh2' `dsvar'X`m2'X`qh3' `dsvar'X`m2'X`qh4' `dsvar'X`m2'X`qh5';
	test `dsvar'X`m1'X`qh1'-`dsvar'X`m1'X`qh5' = 0;
	test `dsvar'X`m1'X`qh1'-`dsvar'X`m1'X`qh4' = 0;
	test `dsvar'X`m2'X`qh1'-`dsvar'X`m2'X`qh5' = 0;

	* Columns 6;
	local dsvar downmeasure;
	
	areg imp_intrafirm `dsvar'X`m1'X`qh1' `dsvar'X`m1'X`qh2' `dsvar'X`m1'X`qh3' `dsvar'X`m1'X`qh4' `dsvar'X`m1'X`qh5' 
		`dsvar'X`m2'X`qh1' `dsvar'X`m2'X`qh2' `dsvar'X`m2'X`qh3' `dsvar'X`m2'X`qh4' `dsvar'X`m2'X`qh5' 
		`m1'X`qh1' `m1'X`qh2' `m1'X`qh3' `m1'X`qh4' `m1'X`qh5' `m2'X`qh2' `m2'X`qh3' `m2'X`qh4' `m2'X`qh5' `wfactorcontrols' `wdisp' [aw=tot_imp], 
		absorb(ctyyear) cluster(io2002);
	outreg2 `dsvar'X`m1'X`qh1' `dsvar'X`m1'X`qh2' `dsvar'X`m1'X`qh3' `dsvar'X`m1'X`qh4' `dsvar'X`m1'X`qh5' 
		`dsvar'X`m2'X`qh1' `dsvar'X`m2'X`qh2' `dsvar'X`m2'X`qh3' `dsvar'X`m2'X`qh4' `dsvar'X`m2'X`qh5' 
		`m1'X`qh1' `m1'X`qh2' `m1'X`qh3' `m1'X`qh4' `m1'X`qh5' `m2'X`qh2' `m2'X`qh3' `m2'X`qh4' `m2'X`qh5' `wfactorcontrols' `wdisp' using `ofile', 
		append `defoptions';
	test `dsvar'X`m1'X`qh1' `dsvar'X`m1'X`qh2' `dsvar'X`m1'X`qh3' `dsvar'X`m1'X`qh4' `dsvar'X`m1'X`qh5' 
		`dsvar'X`m2'X`qh1' `dsvar'X`m2'X`qh2' `dsvar'X`m2'X`qh3' `dsvar'X`m2'X`qh4' `dsvar'X`m2'X`qh5';
	test `dsvar'X`m1'X`qh1'-`dsvar'X`m1'X`qh5' = 0;
	test `dsvar'X`m1'X`qh1'-`dsvar'X`m1'X`qh4' = 0;
	test `dsvar'X`m2'X`qh1'-`dsvar'X`m2'X`qh5' = 0;

log close;




	
