# delimit ;
clear all;
set memory 400m;
set more off;

* Name of working directory;
local dir "C:\Users\davinchor\Documents\Projects\Trade-Production Line\Antras-Chor Replication Material";
cd "`dir'";

******************************************************;
* TABLE 9: DOWNSTREAMNESS BY QUINTILES ;
******************************************************;

local mergelist "downstreamness IOsigmas factorintensities 
 	randdintensity dispersion";


* START WITH INDUSTRY-YEAR REGRESSIONS;

use USIOrelatedparty.dta, clear;
keep if year>=2000 & year<=2010;
collapse (sum) imp_non imp_rel, by(io2002 year);
gen imp_intrafirm = imp_rel/(imp_non+imp_rel);
lab var imp_intrafirm "Intrafirm imports";
gen tot_imp = imp_rel+imp_non;
la var tot_imp "Total imports";
foreach f of local mergelist {;
	merge n:1 io2002 using `f';
	drop if _m==2;
	drop _m;
};
keep if substr(io2002,1,1)=="3" & imp_intrafirm~=.;
compress;

foreach s of numlist 1/2 {;
	local m`s' w1M`s'sigma;
};
foreach s of numlist 1/5 {;
	local q`s' w1Q`s'sigma;
};

local logfile Table9.log;
local ofile Table9.out;
local defoptions "dec(3) coefastr se bracket nocons excel";
cap erase `ofile';
cap erase `logfile';

cap log close;
log using `logfile', replace;

	areg imp_intrafirm year, absorb(year) cluster(io2002);
	outreg2 year using `ofile', replace `defoptions';


	* Columns 1 and 2; 
	local dsvar duse_tuse;

	foreach t of numlist 1/5 {;
		local qd`t' Q`t'`dsvar';
	};
		
	foreach s of numlist 1/2 {;
		foreach t of numlist 1/5 {;
			cap drop `qd`t''X`m`s'';
			g `qd`t''X`m`s''=`qd`t''*`m`s'';
		};
	};
	
	local wfactorcontrols "w1ls_l_0005 w1lkequip_l_0005 w1lkplant_l_0005 w1lm_l_0005 w1lus_randd_intensity_0005";
	local wdisp "w1disp3_2000";
	
	areg imp_intrafirm `qd1'X`m1' `qd2'X`m1' `qd3'X`m1' `qd4'X`m1' `qd5'X`m1' `qd2'X`m2' `qd3'X`m2' `qd4'X`m2' `qd5'X`m2'
		`wfactorcontrols' `wdisp', absorb(year) cluster(io2002);
	outreg2 `qd1'X`m1' `qd2'X`m1' `qd3'X`m1' `qd4'X`m1' `qd5'X`m1' `qd2'X`m2' `qd3'X`m2' `qd4'X`m2' `qd5'X`m2'
		`wfactorcontrols' `wdisp' using `ofile', append `defoptions' ctitle(`depvar');	
	test `qd1'X`m1' `qd2'X`m1' `qd3'X`m1' `qd4'X`m1' `qd5'X`m1' `qd2'X`m2' `qd3'X`m2' `qd4'X`m2' `qd5'X`m2';
	test `qd1'X`m1'-`qd5'X`m1'=0;
	test `qd5'X`m2'=0;
	
	areg imp_intrafirm `qd1'X`m1' `qd2'X`m1' `qd3'X`m1' `qd4'X`m1' `qd5'X`m1' `qd2'X`m2' `qd3'X`m2' `qd4'X`m2' `qd5'X`m2'
		`wfactorcontrols' `wdisp' [aw=tot_imp], absorb(year) cluster(io2002);
	outreg2 `qd1'X`m1' `qd2'X`m1' `qd3'X`m1' `qd4'X`m1' `qd5'X`m1' `qd2'X`m2' `qd3'X`m2' `qd4'X`m2' `qd5'X`m2'
		`wfactorcontrols' `wdisp' using `ofile', append `defoptions' ctitle(`depvar');	
	test `qd1'X`m1' `qd2'X`m1' `qd3'X`m1' `qd4'X`m1' `qd5'X`m1' `qd2'X`m2' `qd3'X`m2' `qd4'X`m2' `qd5'X`m2';
	test `qd1'X`m1'-`qd5'X`m1'=0;
	test `qd5'X`m2'=0;

	* Columns 4 and 5;
	local dsvar downmeasure;
	
	foreach t of numlist 1/5 {;
		local qd`t' Q`t'`dsvar';
	};
		
	foreach s of numlist 1/2 {;
		foreach t of numlist 1/5 {;
			cap drop `qd`t''X`m`s'';
			g `qd`t''X`m`s''=`qd`t''*`m`s'';
		};
	};
	
	areg imp_intrafirm `qd1'X`m1' `qd2'X`m1' `qd3'X`m1' `qd4'X`m1' `qd5'X`m1' `qd2'X`m2' `qd3'X`m2' `qd4'X`m2' `qd5'X`m2'
		`wfactorcontrols' `wdisp', absorb(year) cluster(io2002);
	outreg2 `qd1'X`m1' `qd2'X`m1' `qd3'X`m1' `qd4'X`m1' `qd5'X`m1' `qd2'X`m2' `qd3'X`m2' `qd4'X`m2' `qd5'X`m2'
		`wfactorcontrols' `wdisp' using `ofile', append `defoptions' ctitle(`depvar');	
	test `qd1'X`m1' `qd2'X`m1' `qd3'X`m1' `qd4'X`m1' `qd5'X`m1' `qd2'X`m2' `qd3'X`m2' `qd4'X`m2' `qd5'X`m2';
	test `qd1'X`m1'-`qd5'X`m1'=0;
	test `qd5'X`m2'=0;
	
	areg imp_intrafirm `qd1'X`m1' `qd2'X`m1' `qd3'X`m1' `qd4'X`m1' `qd5'X`m1' `qd2'X`m2' `qd3'X`m2' `qd4'X`m2' `qd5'X`m2'
		`wfactorcontrols' `wdisp' [aw=tot_imp], absorb(year) cluster(io2002);
	outreg2 `qd1'X`m1' `qd2'X`m1' `qd3'X`m1' `qd4'X`m1' `qd5'X`m1' `qd2'X`m2' `qd3'X`m2' `qd4'X`m2' `qd5'X`m2'
		`wfactorcontrols' `wdisp' using `ofile', append `defoptions' ctitle(`depvar');	
	test `qd1'X`m1' `qd2'X`m1' `qd3'X`m1' `qd4'X`m1' `qd5'X`m1' `qd2'X`m2' `qd3'X`m2' `qd4'X`m2' `qd5'X`m2';
	test `qd1'X`m1'-`qd5'X`m1'=0;
	test `qd5'X`m2'=0;
	
	
log close;



* COUNTRY-INDUSTRY-YEAR REGRESSIONS;

use USIOrelatedparty.dta, clear;
keep if year>=2000 & year<=2010;
collapse (sum) imp_non imp_rel, by(isocode io2002 year);
gen imp_intrafirm = imp_rel/(imp_non+imp_rel);
lab var imp_intrafirm "Intrafirm imports";
gen tot_imp = imp_rel+imp_non;
la var tot_imp "Total imports";
foreach f of local mergelist {;
	merge n:1 io2002 using `f';
	drop if _m==2;
	drop _m;
};
keep if substr(io2002,1,1)=="3" & imp_intrafirm~=.;
egen ctyyear=group(isocode year);
compress;

log using `logfile', append;

	local wfactorcontrols "w1ls_l_0005 w1lkequip_l_0005 w1lkplant_l_0005 w1lm_l_0005 w1lus_randd_intensity_0005";
	local wdisp "w1disp3_2000";
	
	* Columns 3;
	local dsvar duse_tuse;
	
	foreach t of numlist 1/5 {;
		local qd`t' Q`t'`dsvar';
	};
		
	foreach s of numlist 1/2 {;
		foreach t of numlist 1/5 {;
			cap drop `qd`t''X`m`s'';
			g `qd`t''X`m`s''=`qd`t''*`m`s'';
		};
	};
	
	areg imp_intrafirm `qd1'X`m1' `qd2'X`m1' `qd3'X`m1' `qd4'X`m1' `qd5'X`m1' `qd2'X`m2' `qd3'X`m2' `qd4'X`m2' `qd5'X`m2'
		`wfactorcontrols' `wdisp' [aw=tot_imp], absorb(ctyyear) cluster(io2002);
	outreg2 `qd1'X`m1' `qd2'X`m1' `qd3'X`m1' `qd4'X`m1' `qd5'X`m1' `qd2'X`m2' `qd3'X`m2' `qd4'X`m2' `qd5'X`m2'
		`wfactorcontrols' `wdisp' using `ofile', append `defoptions' ctitle(`depvar');	
	test `qd1'X`m1' `qd2'X`m1' `qd3'X`m1' `qd4'X`m1' `qd5'X`m1' `qd2'X`m2' `qd3'X`m2' `qd4'X`m2' `qd5'X`m2';
	test `qd1'X`m1'-`qd5'X`m1'=0;
	test `qd5'X`m2'=0;
	

	* Columns 6;
	local dsvar downmeasure;

	foreach t of numlist 1/5 {;
		local qd`t' Q`t'`dsvar';
	};
		
	foreach s of numlist 1/2 {;
		foreach t of numlist 1/5 {;
			cap drop `qd`t''X`m`s'';
			g `qd`t''X`m`s''=`qd`t''*`m`s'';
		};
	};
	
	areg imp_intrafirm `qd1'X`m1' `qd2'X`m1' `qd3'X`m1' `qd4'X`m1' `qd5'X`m1' `qd2'X`m2' `qd3'X`m2' `qd4'X`m2' `qd5'X`m2'
		`wfactorcontrols' `wdisp' [aw=tot_imp], absorb(ctyyear) cluster(io2002);
	outreg2 `qd1'X`m1' `qd2'X`m1' `qd3'X`m1' `qd4'X`m1' `qd5'X`m1' `qd2'X`m2' `qd3'X`m2' `qd4'X`m2' `qd5'X`m2'
		`wfactorcontrols' `wdisp' using `ofile', append `defoptions' ctitle(`depvar');	
	test `qd1'X`m1' `qd2'X`m1' `qd3'X`m1' `qd4'X`m1' `qd5'X`m1' `qd2'X`m2' `qd3'X`m2' `qd4'X`m2' `qd5'X`m2';
	test `qd1'X`m1'-`qd5'X`m1'=0;
	test `qd5'X`m2'=0;

log close;




	
